==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectionChangedEventArgsDescription } from "./GridSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridSelectionChangedEventArgsDescriptionMetadata, _super);
    function GridSelectionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectionChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectionChangedEventArgsDescriptionMetadata.c(GridSelectionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridSelectionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridSelectionChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    GridSelectionChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectionChangedEventArgsDescriptionMetadata.b(a);
        a.ac("GridSelectionChangedEventArgs", function () { return new GridSelectionChangedEventArgsDescription(); });
        a.ab("GridSelectionChangedEventArgs", GridSelectionChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectionChangedEventArgsDescriptionMetadata.$t = markType(GridSelectionChangedEventArgsDescriptionMetadata, 'GridSelectionChangedEventArgsDescriptionMetadata');
    GridSelectionChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectionChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectionChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectionChangedEventArgsDescription } from "./GridSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectionChangedEventArgsDescriptionMetadata, _super);
    function GridSelectionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectionChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectionChangedEventArgsDescriptionMetadata.c(GridSelectionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridSelectionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridSelectionChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    GridSelectionChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectionChangedEventArgsDescriptionMetadata.b(a);
        a.ae("GridSelectionChangedEventArgs", function () { return new GridSelectionChangedEventArgsDescription(); });
        a.ad("GridSelectionChangedEventArgs", GridSelectionChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectionChangedEventArgsDescriptionMetadata.$t = markType(GridSelectionChangedEventArgsDescriptionMetadata, 'GridSelectionChangedEventArgsDescriptionMetadata');
    GridSelectionChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectionChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectionChangedEventArgsDescriptionMetadata };
